/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.managed.api.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.jboss.managed.spi.factory.ManagedPropertyConstraintsPopulatorFactory;

/**
 * An annotation describing the ManagedPropertyConstraintsPopulatorFactory
 * for a property.
 * This can be used on fields,methods for an individual property, or on a type
 * to specify the default factory for all properties in a managed object.
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision:$
 */
@Target({ElementType.TYPE, ElementType.METHOD, ElementType.FIELD})
@Retention(RetentionPolicy.RUNTIME)
public @interface ConstraintsPopulatorFactory
{
   /** The constraints, allowed values populator factory */
   Class<? extends ManagedPropertyConstraintsPopulatorFactory> value();
   /** Optional string representation of min value */
   String min() default "";
   /** Optional string representation of max value */
   String max() default "";
   /** Optional string representation of legal values */
   String[] legalValues() default {};
   /** Optional arguments to pass to the factory */
   String[] args() default {};
}
